﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.WindowsAzure;
using Microsoft.WindowsAzure.StorageClient;
using Microsoft.WindowsAzure.StorageClient.Protocol;
using System.Net;
using System.IO;
using smarx.LeaseBlobExtensions;

namespace LeaseBlobTest
{
    class Program
    {
        static void Main(string[] args)
        {
            var account = CloudStorageAccount.Parse("UseDevelopmentStorage=true"); // or your real connection string
            var blobs = account.CreateCloudBlobClient();
            var container = blobs.GetContainerReference("container");
            container.CreateIfNotExist();
            var blob = container.GetBlobReference("blob");
            blob.UploadText("contents");

            Console.WriteLine("Acquiring lease...");
            var leaseId = blob.AcquireLease();
            Console.WriteLine(string.Format("\tGot lease: '{0}'", leaseId));

            Console.WriteLine("Trying to change contents without the lease...");
            try
            {
                blob.UploadText("new contents");
            }
            catch (Exception e)
            {
                Console.WriteLine(string.Format("\tFailed (as expected) with '{0}'", e.Message));
            }

            Console.WriteLine("Trying to acquire a different lease...");
            try
            {
                blob.AcquireLease();
            }
            catch (Exception e)
            {
                Console.WriteLine(string.Format("\tFailed (as expected) with '{0}'", e.Message));
            }

            Console.WriteLine("Modifying blob (with lease)...");
            blob.UploadText("new contents", leaseId);
            Console.WriteLine("\tSuccess!");

            Console.WriteLine("Reading blob without lease...");
            Console.WriteLine(string.Format("\tGot text: '{0}'", blob.DownloadText()));

            Console.WriteLine("Renewing the lease...");
            blob.RenewLease(leaseId);
            Console.WriteLine("\tSuccess!");

            Console.WriteLine("Breaking the lease...");
            blob.BreakLease();
            Console.WriteLine("\tSuccess!");

            Console.WriteLine("Trying to renew the lease...");
            try
            {
                blob.RenewLease(leaseId);
            }
            catch (Exception e)
            {
                Console.WriteLine(string.Format("\tFailed (as expected) with '{0}'", e.Message));
            }

            Console.WriteLine("Releasing the original lease...");
            blob.ReleaseLease(leaseId);
            Console.WriteLine("\tSuccess!");
        }
    }
}